@@ -19,7 +19,8 @@ class FacebookCommentCache(models.Model):
 			return []
 		try:
 			comments = json.loads(obj.content)
-			data = comments[href]['data']
+			data = comments[href]['comments']['data']
 		except (ValueError, AttributeError, KeyError):
 			return []
 		return data
+
